<?php

namespace App\Http\Controllers;

use App\Models\product_model;
use Illuminate\Http\Request;

class product_controller extends Controller
{
    protected $products;

    public function __construct(){
        $this->products = new product_model;
    }

    public function product_list(){

        $products = $this->products->all();
        $data = compact('products');

        return view('products')->with($data);
    }

    public function add(){

        $url = route('product_form');
        $title = 'Add Product';
        $product = $this->products;

        $data = compact('product','url','title');

        return view('product_form')->with($data);
    }

    public function store(Request $request)
    {
        $request->validate([
            'name' => 'required',
            'price' => 'required',
            'quantity' => 'required',
            'size' => 'required',
            'image' => 'required|image|mimes:jpg,jpeg,png,gif|max:2048',
        ]);

        $product = $this->products;

        // Handle image upload
        if ($request->hasFile('image')) {
            $image = $request->file('image');
            $extension = $image->getClientOriginalExtension();
            $filename = time() . '_' . $request->size . '.' . $extension;

            // Store in public/img
            $image->move(public_path('img'), $filename);

            // Save filename to DB
            $product->image = $filename;
        }

        // Save other fields
        $product->name = $request->name;
        $product->price = $request->price;
        $product->quantity = $request->quantity;
        $product->size = $request->size;

        $product->save();

        return redirect()->route('products')->with('success', 'Product added successfully!');
    }

    public function delete($id){

        $product = $this->products->find($id);

        if(!is_null($product)){

            $imagePath = public_path('img/' . $product->image);
            if (file_exists($imagePath)) {
                unlink($imagePath); // Delete the image file
            }

            $product->delete();
        }

        return redirect(route('products'));
    }

    public function edit($id){

        $product = $this->products->find($id);

        if(is_null($product)){
            return redirect(route('products'));
        }else{

            $url = route('update_product', ['id' => $id]);
            $title = 'Edit Product';

            $data = compact('product','url','title');

            return view('product_form')->with($data);
        }
    }

    public function update($id, Request $request)
    {
        $request->validate([
            'name' => 'required',
            'price' => 'required',
            'quantity' => 'required',
            'size' => 'required',
            'image' => 'nullable|image|mimes:jpg,jpeg,png,gif|max:2048',
        ]);

        $product = $this->products->find($id);
        if (!$product) {
            return redirect()->route('products')->with('error', 'Product not found!');
        }

        if ($request->hasFile('image')) {

            $oldImagePath = public_path('img/' . $product->image);
            if (file_exists($oldImagePath)) {
                unlink($oldImagePath);
            }

            $image = $request->file('image');
            $extension = $image->getClientOriginalExtension();
            $filename = time() . '_' . $request->size . '.' . $extension;

            $image->move(public_path('img'), $filename);
            $product->image = $filename;
        }

        $product->name = $request->name;
        $product->price = $request->price;
        $product->quantity = $request->quantity;
        $product->size = $request->size;
        $product->save();

        return redirect()->route('products')->with('success', 'Product updated successfully!');
    }


}
