(function ($) {

    console.log('jquery js');

    let baseUrl = $('meta[name="base-url"]').attr('content');


    $(document).ready(function() {
        $('#custom_budget').prop('disabled', true);

        // When the checkbox is clicked, disable or enable the input field
        $('#custom_budget_checkbox').change(function() {
            if ($(this).is(':checked')) {
                // Disable the input field if the checkbox is checked
                $('#budget').prop('disabled', true);
                $('#custom_budget').prop('disabled', false);
            } else {
                // Enable the input field if the checkbox is unchecked
                $('#budget').prop('disabled', false);
                $('#custom_budget').prop('disabled', true);
            }
        });

        // Initial check to disable the input field if the checkbox is already checked on page load
        if ($('#custom_budget_checkbox').is(':checked')) {
            $('#custom_budget').prop('disabled', true);
        }
    });

    // For Add Cart Items For Checkout
    $('.add_to_cart').on('click', function () {
        var id = $(this).data('id');

        $.ajax({
            url: baseUrl + '/products/add-to-cart',
            // url: '/products/add-to-cart', // Route URL
            type: 'POST',
            data: {
                id: id,
                _token: $('meta[name="csrf-token"]').attr('content') // Important for Laravel
            },
            success: function(response) {

                let existingRow = $(`.cart_items tr#${response.id}`);

                if (existingRow.length > 0) {
                    // Get current quantity
                    let qtyTd = existingRow.find('td.qty');
                    let currentQty = parseInt(qtyTd.text()) || 0;
                    qtyTd.text(currentQty + 1);
                } else {
                    // Add new row if not exists
                    $('.cart_items').prepend(`
                        <tr class="cart_item" id="${response.id}">
                            <td class="qty">1</td>
                            <td class="name">${response.name}</td>
                            <td class="price">${response.price}</td>
                            <td class="action"><i class="fa-solid fa-circle-minus delete_cart_item"></i></td>
                        </tr>
                    `);
                }

                let total = 0;
                $('.cart_items tr.cart_item').each(function () {
                    let qty = parseInt($(this).find('.qty').text()) || 0;
                    let price = parseFloat($(this).find('.price').text()) || 0;
                    total += qty * price;
                });

                $('.cart_items .total').text(total.toFixed(2));
            },
            error: function(xhr) {
                console.log('Error:', xhr.responseText);
            }
        });
    });

    // For Delete Cart Item
    $(document).on('click', '.cart_items .action i.delete_cart_item', function () {
        const row = $(this).closest('tr');
        row.remove();

        // Recalculate total after removal
        let total = 0;
        $('.cart_items tr.cart_item').each(function () {
            let qty = parseInt($(this).find('.qty').text()) || 0;
            let price = parseFloat($(this).find('.price').text()) || 0;
            total += qty * price;
        });

        $('.cart_items .total').text(total.toFixed(2));
    });

    // For Checkout Cart Items
    $('.check_out').on('click', function () {
        let cartData = [];

        $('.cart_items .cart_item').each(function () {
            let id = $(this).attr('id');
            let qty = $(this).find('.qty').text();
            let name = $(this).find('.name').text();
            let price = $(this).find('.price').text();

            cartData.push({
                id: id,
                name: name,
                price: price,
                quantity: qty,
            });
        });

        let total = $('.cart_items .total').text();

        // console.log('Cart Data:', cartData);

        $.ajax({
            url: baseUrl + '/products/checkout',
            // url: '/products/checkout',
            type: 'POST',
            data: {
                cart_data: cartData,
                total: total,
                _token: $('meta[name="csrf-token"]').attr('content') // Important for Laravel
            },
            success: function(response) {

                // window.location.href = baseUrl + '/products';
                console.log('res: ',response);

            },
            error: function(xhr) {
                console.log('Error:', xhr.responseText);
            }
        });

    });


})(jQuery);
